var namespacecom_1_1sun_1_1star_1_1drawing =
[
    [ "BarCodeErrorCorrection", "namespacecom_1_1sun_1_1star_1_1drawing_1_1BarCodeErrorCorrection.html", [
      [ "HIGH", "namespacecom_1_1sun_1_1star_1_1drawing_1_1BarCodeErrorCorrection.html#ae3e154799ea6ef298bac275c4bda5a80", null ],
      [ "LOW", "namespacecom_1_1sun_1_1star_1_1drawing_1_1BarCodeErrorCorrection.html#adda60ffdf519098c713f07d7c7384008", null ],
      [ "MEDIUM", "namespacecom_1_1sun_1_1star_1_1drawing_1_1BarCodeErrorCorrection.html#a3de0347c2dfa277a66e9ae7cc1baf1cb", null ],
      [ "QUARTILE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1BarCodeErrorCorrection.html#a25da968a907a279652d411dac2d30924", null ]
    ] ],
    [ "CanvasFeature", "namespacecom_1_1sun_1_1star_1_1drawing_1_1CanvasFeature.html", [
      [ "None", "namespacecom_1_1sun_1_1star_1_1drawing_1_1CanvasFeature.html#a32d3c97dbc752e0c0ae5826672a15ba5", null ],
      [ "SpriteCanvas", "namespacecom_1_1sun_1_1star_1_1drawing_1_1CanvasFeature.html#a409db1ae67dad49a23eb807cf915a420", null ]
    ] ],
    [ "CaptionEscapeDirection", "namespacecom_1_1sun_1_1star_1_1drawing_1_1CaptionEscapeDirection.html", [
      [ "auto", "namespacecom_1_1sun_1_1star_1_1drawing_1_1CaptionEscapeDirection.html#acae9fd798002010a25c3087215a5f9f2", null ],
      [ "horizontal", "namespacecom_1_1sun_1_1star_1_1drawing_1_1CaptionEscapeDirection.html#ab286220c6f6db08072029292bcc7b79b", null ],
      [ "vertical", "namespacecom_1_1sun_1_1star_1_1drawing_1_1CaptionEscapeDirection.html#a29345e899c6c5c0c3b81d3292dc9ea62", null ]
    ] ],
    [ "CaptionType", "namespacecom_1_1sun_1_1star_1_1drawing_1_1CaptionType.html", [
      [ "angled", "namespacecom_1_1sun_1_1star_1_1drawing_1_1CaptionType.html#a2be9d51260d858d19c414821fe47894c", null ],
      [ "connector", "namespacecom_1_1sun_1_1star_1_1drawing_1_1CaptionType.html#abcfe7b2ee4579cfa6d42735746947c5e", null ],
      [ "straight", "namespacecom_1_1sun_1_1star_1_1drawing_1_1CaptionType.html#aa74158b0a461b1ad2ce73abc221de400", null ]
    ] ],
    [ "EnhancedCustomShapeGluePointType", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeGluePointType.html", [
      [ "CUSTOM", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeGluePointType.html#a2557162a796a84ca7a80767a42f777a3", null ],
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeGluePointType.html#a87d5fdeecd058bf6c4bf4fddb6724cd8", null ],
      [ "RECT", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeGluePointType.html#a8689d7e0bee31d47768177433cc0e36b", null ],
      [ "SEGMENTS", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeGluePointType.html#af34fe62f1323f6cb94a09d636fc02d1f", null ]
    ] ],
    [ "EnhancedCustomShapeMetalType", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeMetalType.html", [
      [ "MetalMSCompatible", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeMetalType.html#a3fc92560ae1a380ff578503dcd474821", null ],
      [ "MetalODF", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeMetalType.html#a9b20a96e43c083139e4cc0a4fe4a3036", null ]
    ] ],
    [ "EnhancedCustomShapeParameterType", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html", [
      [ "ADJUSTMENT", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#a1cce3c710e08b49264e6b308c9e229b0", null ],
      [ "BOTTOM", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#a047e134a70c9674c249189da852b7a2f", null ],
      [ "EQUATION", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#af7239d10b186d5cc5c05e7892dab7f00", null ],
      [ "HASFILL", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#a3406dbecb446cae7fa186233baa2c9a8", null ],
      [ "HASSTROKE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#aa53a1096f7c01cfaba015c3cfbb08549", null ],
      [ "HEIGHT", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#a26254dd2f0d9570e1f6bd365332451e7", null ],
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#a105d61332f9450fb1986a38e7243c3aa", null ],
      [ "LOGHEIGHT", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#aee9cb2e7dd25c485f3aa90ab5ac87a7e", null ],
      [ "LOGWIDTH", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#a578313de5fda2a42b7ff8e2ac5fcdad3", null ],
      [ "NORMAL", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#a2b928e4af79661f033263d46abdead07", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#a0149ac9c0344cfbfd5771ce1a96af612", null ],
      [ "TOP", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#a49aa8a416f8c0c420ee0003a70a10396", null ],
      [ "WIDTH", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#a87ec447127204e16270370d3fb326a46", null ],
      [ "XSTRETCH", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#ac4615c209adb8c34f0cc655e8c86ba02", null ],
      [ "YSTRETCH", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterType.html#ab89518240a0d5d6746a5b280d1dc25ef", null ]
    ] ],
    [ "EnhancedCustomShapeSegmentCommand", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html", [
      [ "ANGLEELLIPSE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a1a4871e4aa8c72f86b0c045649d1562c", null ],
      [ "ANGLEELLIPSETO", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a514a3e6a181fed964f7c84245756275c", null ],
      [ "ARC", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a2b33cac67125ebf8ab5bbe58d83d4d77", null ],
      [ "ARCANGLETO", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a9fa5dd870fc1d47a3ad86227116f518a", null ],
      [ "ARCTO", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a6857980068cd6a6b76197067c52dbc28", null ],
      [ "CLOCKWISEARC", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a4cfeb00d61ae01e4d79e864429de6522", null ],
      [ "CLOCKWISEARCTO", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a3790bb4b78111712cced80083dfcfe46", null ],
      [ "CLOSESUBPATH", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a4261669b669e6a48649b4feea93e9308", null ],
      [ "CURVETO", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#aabfcb314a562febd5b938ffaff7c30c8", null ],
      [ "DARKEN", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#acfed2a86369d0f6ac4bf90dc26f3295d", null ],
      [ "DARKENLESS", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#ae2d4b7df820bcf706ce797b3c5247deb", null ],
      [ "ELLIPTICALQUADRANTX", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a23cdb3a8921c0ac342e3b4090ced8ab8", null ],
      [ "ELLIPTICALQUADRANTY", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a873cacef3742d376627cf3297ae791e8", null ],
      [ "ENDSUBPATH", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a398b5504f377917abf0e94656d00ffb8", null ],
      [ "LIGHTEN", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a377f8410f20576a8fcd748e2e6d54e0a", null ],
      [ "LIGHTENLESS", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a9dea95ac404d823c2acb5658a8cd9027", null ],
      [ "LINETO", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a13d59aa30f5c83e1e0b25c2ee06efb06", null ],
      [ "MOVETO", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a32f14ef0873582aa2fdb55ae8896af74", null ],
      [ "NOFILL", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a6e15f9afb26de0a07bf35642e22f673f", null ],
      [ "NOSTROKE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a4ec61d5065d15acfe1b41a1eae2bb370", null ],
      [ "QUADRATICCURVETO", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#a691b41c520ee6349eabbee14bdf6e3ed", null ],
      [ "UNKNOWN", "namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html#aeecf8d431c447c75cb711133a932f0fd", null ]
    ] ],
    [ "framework", "namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html", [
      [ "AnchorBindingMode", "namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html#af2624f1e14ec2ab7890946d97b26724c", [
        [ "DIRECT", "namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html#af2624f1e14ec2ab7890946d97b26724ca1ea328a644e627283a35716a54108248", null ],
        [ "INDIRECT", "namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html#af2624f1e14ec2ab7890946d97b26724caa70fc5026d3a310a836fa57ac51d8a4e", null ]
      ] ]
    ] ],
    [ "ShadingPattern", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html", [
      [ "CLEAR", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a9c8496e9c4c0490a148840cc0bdebbcb", null ],
      [ "DIAG_CROSS", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#ae104908eeee12239462cb41f1459ebee", null ],
      [ "DIAG_STRIPE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#acf21720b2db4350afb0c3f6d92fda891", null ],
      [ "HORZ_CROSS", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a76714b76c0713f540d986afa1503c92f", null ],
      [ "HORZ_STRIPE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#aef783dec0fba39570d5eb0f488012656", null ],
      [ "NIL", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a23f25d36bc65773c4799028309d91f90", null ],
      [ "PCT10", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a7d55bede5802dccdf3d98c285b0f5e02", null ],
      [ "PCT12", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a47adf595017939f72b0df095b815aa4e", null ],
      [ "PCT15", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a1b8e7112644ab1dc9a07aa40235ab8ab", null ],
      [ "PCT17", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a1e19dcfc8ae4c16ceab3991c1afb6272", null ],
      [ "PCT2", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a43b7f28e5bf7fe11d598d2ff0312ea9c", null ],
      [ "PCT20", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#ab1fabd47c7e7a78f23ab1d8953e76f29", null ],
      [ "PCT22", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a753ffb83165937dcb064c095703d1851", null ],
      [ "PCT25", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a1efe19e48ffc0e39a6f67e4ab44a050f", null ],
      [ "PCT27", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a4fbab6dd5f37b4343c9bff5056414273", null ],
      [ "PCT30", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#ac0170bc032ac55f7eb6d7d331825b376", null ],
      [ "PCT32", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#aa4c6447b3399b8052c6339039a95632b", null ],
      [ "PCT35", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#ae13f7e887b4d8cd128153e6fb0a9671c", null ],
      [ "PCT37", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a959f99920e14942859482849eb57b010", null ],
      [ "PCT40", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#add6c61bea95b26a787d8a58bf250bfbb", null ],
      [ "PCT42", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a9e5ac7a7788e54716b9235dbc8f1f7df", null ],
      [ "PCT45", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a04cb113da18856890681b2825ab83e03", null ],
      [ "PCT47", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#aa5ff429240e052226a1323fde6a29312", null ],
      [ "PCT5", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a82681c45b2be4fcf02b7e8741c13d8eb", null ],
      [ "PCT50", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a6a745077764506a8596cfb27de423225", null ],
      [ "PCT52", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a8717d155fc4787209956b54a9874bc22", null ],
      [ "PCT55", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#af4450b00039fd6a393939dd6778f739c", null ],
      [ "PCT57", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a13f66379349720c7cf3243260431e11d", null ],
      [ "PCT60", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a621c7f52d5d072e7fe2241a7139adf3a", null ],
      [ "PCT62", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a5e5518d29a26daf0c3d1f4385220559d", null ],
      [ "PCT65", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#aa0724f24443953fa812a0cf410e50b89", null ],
      [ "PCT67", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a322d8827f57243ff8ce2fbad6bf6322b", null ],
      [ "PCT7", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a90127bed7ad3fe6394a62028b3a4259e", null ],
      [ "PCT70", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#af2125cca0686aa7dcf4d25b5a76bbe24", null ],
      [ "PCT72", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a2aafa5c90f6ca8426cabfb2290a94de1", null ],
      [ "PCT75", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a6ba95ee262461b5350edb90071c41832", null ],
      [ "PCT77", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#af96a236745018ac0acf5ed9cb8ea6849", null ],
      [ "PCT80", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a06dd7d336fc3ba400a94206937a50002", null ],
      [ "PCT82", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a28716bf5d39ff498290967fbefea94f6", null ],
      [ "PCT85", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a9a55a1bec41cbcffefb5639579676eba", null ],
      [ "PCT87", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a9b32961d09b346b6d7de775792676cfc", null ],
      [ "PCT90", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a239488009151d8a6c8949792f9009232", null ],
      [ "PCT92", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#aaa63632a6fadb0cc89ba8f05ca68dd4d", null ],
      [ "PCT95", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a0837d0b9d939006e463cb6cef64a1fe4", null ],
      [ "PCT97", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#afa621e23f53ce1a75b68fb79c1469569", null ],
      [ "REVERSE_DIAG_STRIPE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a17b34f2a8f50e7d7ec10d44e636c9440", null ],
      [ "SOLID", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a410b3745448e9538d9d6b8d551e63e60", null ],
      [ "THIN_DIAG_CROSS", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#ad43a4f0ea33fe4b7f74c0cbfbf250b3f", null ],
      [ "THIN_DIAG_STRIPE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a5779354a00d13d99fc615d40626c50dd", null ],
      [ "THIN_HORZ_CROSS", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a49e547149fa428848c930b8cae6270e7", null ],
      [ "THIN_HORZ_STRIPE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a3a73f7304721430fbb38ce177e48aad5", null ],
      [ "THIN_REVERSE_DIAG_STRIPE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#acf82e0a9698b482b120535d0916c8e82", null ],
      [ "THIN_VERT_STRIPE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a0f7f1879da971b2d3a64b2c34bc44f98", null ],
      [ "UNUSED_1", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#ad9283ed155918b747e20ce4ab423d972", null ],
      [ "UNUSED_2", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a4abaf1b4d20c05d06f10ca3ce6509a5e", null ],
      [ "UNUSED_3", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#af641beb29db7e60e5c019eb79b725a61", null ],
      [ "UNUSED_4", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a332a78f540bd8c5f21f237e43dc0bd7a", null ],
      [ "UNUSED_5", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a21b3ad1294fadb91bdac6015d426b0e5", null ],
      [ "UNUSED_6", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a72c4a843204322538674521571c1fcf8", null ],
      [ "UNUSED_7", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a4f5a2c4acd1ea63e505accb62263d23a", null ],
      [ "UNUSED_8", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a362540e6723e337fa12ec7cee42c9538", null ],
      [ "UNUSED_9", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a490f806c5c61b5131d6f1542ce269347", null ],
      [ "VERT_STRIPE", "namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html#a97004c57503f014956897a2e81355e1a", null ]
    ] ],
    [ "AccessibleDrawDocumentView", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleDrawDocumentView.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleDrawDocumentView" ],
    [ "AccessibleGraphControl", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleGraphControl.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleGraphControl" ],
    [ "AccessibleGraphicShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleGraphicShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleGraphicShape" ],
    [ "AccessibleImageBullet", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleImageBullet.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleImageBullet" ],
    [ "AccessibleOLEShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleOLEShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleOLEShape" ],
    [ "AccessibleShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleShape" ],
    [ "AppletShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape" ],
    [ "Background", "servicecom_1_1sun_1_1star_1_1drawing_1_1Background.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1Background" ],
    [ "BarCode", "structcom_1_1sun_1_1star_1_1drawing_1_1BarCode.html", "structcom_1_1sun_1_1star_1_1drawing_1_1BarCode" ],
    [ "BezierPoint", "structcom_1_1sun_1_1star_1_1drawing_1_1BezierPoint.html", "structcom_1_1sun_1_1star_1_1drawing_1_1BezierPoint" ],
    [ "BitmapTable", "servicecom_1_1sun_1_1star_1_1drawing_1_1BitmapTable.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1BitmapTable" ],
    [ "BoundVolume", "structcom_1_1sun_1_1star_1_1drawing_1_1BoundVolume.html", "structcom_1_1sun_1_1star_1_1drawing_1_1BoundVolume" ],
    [ "CameraGeometry", "structcom_1_1sun_1_1star_1_1drawing_1_1CameraGeometry.html", "structcom_1_1sun_1_1star_1_1drawing_1_1CameraGeometry" ],
    [ "CaptionShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape" ],
    [ "ClosedBezierShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1ClosedBezierShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1ClosedBezierShape" ],
    [ "ColorTable", "servicecom_1_1sun_1_1star_1_1drawing_1_1ColorTable.html", null ],
    [ "ConnectorProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1ConnectorProperties.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1ConnectorProperties" ],
    [ "ConnectorShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1ConnectorShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1ConnectorShape" ],
    [ "ControlShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1ControlShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1ControlShape" ],
    [ "CustomShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShape" ],
    [ "CustomShapeEngine", "servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShapeEngine.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShapeEngine" ],
    [ "DashTable", "servicecom_1_1sun_1_1star_1_1drawing_1_1DashTable.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1DashTable" ],
    [ "Defaults", "servicecom_1_1sun_1_1star_1_1drawing_1_1Defaults.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1Defaults" ],
    [ "Direction3D", "structcom_1_1sun_1_1star_1_1drawing_1_1Direction3D.html", "structcom_1_1sun_1_1star_1_1drawing_1_1Direction3D" ],
    [ "DocumentSettings", "servicecom_1_1sun_1_1star_1_1drawing_1_1DocumentSettings.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1DocumentSettings" ],
    [ "DrawingDocument", "servicecom_1_1sun_1_1star_1_1drawing_1_1DrawingDocument.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1DrawingDocument" ],
    [ "DrawingDocumentDrawView", "servicecom_1_1sun_1_1star_1_1drawing_1_1DrawingDocumentDrawView.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1DrawingDocumentDrawView" ],
    [ "DrawingDocumentFactory", "servicecom_1_1sun_1_1star_1_1drawing_1_1DrawingDocumentFactory.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1DrawingDocumentFactory" ],
    [ "DrawPage", "servicecom_1_1sun_1_1star_1_1drawing_1_1DrawPage.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1DrawPage" ],
    [ "DrawPages", "servicecom_1_1sun_1_1star_1_1drawing_1_1DrawPages.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1DrawPages" ],
    [ "EllipseShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1EllipseShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1EllipseShape" ],
    [ "EnhancedCustomShapeAdjustmentValue", "structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeAdjustmentValue.html", "structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeAdjustmentValue" ],
    [ "EnhancedCustomShapeExtrusion", "servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeExtrusion.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeExtrusion" ],
    [ "EnhancedCustomShapeGeometry", "servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeGeometry.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeGeometry" ],
    [ "EnhancedCustomShapeHandle", "servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeHandle.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeHandle" ],
    [ "EnhancedCustomShapeParameter", "structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameter.html", "structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameter" ],
    [ "EnhancedCustomShapeParameterPair", "structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterPair.html", "structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterPair" ],
    [ "EnhancedCustomShapePath", "servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapePath.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapePath" ],
    [ "EnhancedCustomShapeSegment", "structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegment.html", "structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegment" ],
    [ "EnhancedCustomShapeTextFrame", "structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeTextFrame.html", "structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeTextFrame" ],
    [ "EnhancedCustomShapeTextPath", "servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeTextPath.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeTextPath" ],
    [ "FillProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1FillProperties.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1FillProperties" ],
    [ "GenericDrawingDocument", "servicecom_1_1sun_1_1star_1_1drawing_1_1GenericDrawingDocument.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1GenericDrawingDocument" ],
    [ "GenericDrawPage", "servicecom_1_1sun_1_1star_1_1drawing_1_1GenericDrawPage.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1GenericDrawPage" ],
    [ "GluePoint", "structcom_1_1sun_1_1star_1_1drawing_1_1GluePoint.html", "structcom_1_1sun_1_1star_1_1drawing_1_1GluePoint" ],
    [ "GluePoint2", "structcom_1_1sun_1_1star_1_1drawing_1_1GluePoint2.html", "structcom_1_1sun_1_1star_1_1drawing_1_1GluePoint2" ],
    [ "GradientTable", "servicecom_1_1sun_1_1star_1_1drawing_1_1GradientTable.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1GradientTable" ],
    [ "GraphicExportFilter", "servicecom_1_1sun_1_1star_1_1drawing_1_1GraphicExportFilter.html", null ],
    [ "GraphicFilterRequest", "exceptioncom_1_1sun_1_1star_1_1drawing_1_1GraphicFilterRequest.html", "exceptioncom_1_1sun_1_1star_1_1drawing_1_1GraphicFilterRequest" ],
    [ "GraphicObjectShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1GraphicObjectShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1GraphicObjectShape" ],
    [ "GroupShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1GroupShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1GroupShape" ],
    [ "Hatch", "structcom_1_1sun_1_1star_1_1drawing_1_1Hatch.html", "structcom_1_1sun_1_1star_1_1drawing_1_1Hatch" ],
    [ "HatchTable", "servicecom_1_1sun_1_1star_1_1drawing_1_1HatchTable.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1HatchTable" ],
    [ "HomogenMatrix", "structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrix.html", "structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrix" ],
    [ "HomogenMatrix3", "structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrix3.html", "structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrix3" ],
    [ "HomogenMatrix4", "structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrix4.html", "structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrix4" ],
    [ "HomogenMatrixLine", "structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrixLine.html", "structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrixLine" ],
    [ "HomogenMatrixLine3", "structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrixLine3.html", "structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrixLine3" ],
    [ "HomogenMatrixLine4", "structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrixLine4.html", "structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrixLine4" ],
    [ "Layer", "servicecom_1_1sun_1_1star_1_1drawing_1_1Layer.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1Layer" ],
    [ "LayerManager", "servicecom_1_1sun_1_1star_1_1drawing_1_1LayerManager.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1LayerManager" ],
    [ "LineDash", "structcom_1_1sun_1_1star_1_1drawing_1_1LineDash.html", "structcom_1_1sun_1_1star_1_1drawing_1_1LineDash" ],
    [ "LineProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1LineProperties.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1LineProperties" ],
    [ "LineShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1LineShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1LineShape" ],
    [ "MarkerTable", "servicecom_1_1sun_1_1star_1_1drawing_1_1MarkerTable.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1MarkerTable" ],
    [ "MasterPage", "servicecom_1_1sun_1_1star_1_1drawing_1_1MasterPage.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1MasterPage" ],
    [ "MasterPages", "servicecom_1_1sun_1_1star_1_1drawing_1_1MasterPages.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1MasterPages" ],
    [ "MeasureProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1MeasureProperties.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1MeasureProperties" ],
    [ "MeasureShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1MeasureShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1MeasureShape" ],
    [ "ModuleDispatcher", "servicecom_1_1sun_1_1star_1_1drawing_1_1ModuleDispatcher.html", null ],
    [ "OLE2Shape", "servicecom_1_1sun_1_1star_1_1drawing_1_1OLE2Shape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1OLE2Shape" ],
    [ "OpenBezierShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1OpenBezierShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1OpenBezierShape" ],
    [ "PageShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1PageShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1PageShape" ],
    [ "PluginShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1PluginShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1PluginShape" ],
    [ "PolyLineShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1PolyLineShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1PolyLineShape" ],
    [ "PolyPolygonBezierCoords", "structcom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonBezierCoords.html", "structcom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonBezierCoords" ],
    [ "PolyPolygonBezierDescriptor", "servicecom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonBezierDescriptor.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonBezierDescriptor" ],
    [ "PolyPolygonBezierShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonBezierShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonBezierShape" ],
    [ "PolyPolygonDescriptor", "servicecom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonDescriptor.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonDescriptor" ],
    [ "PolyPolygonShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonShape" ],
    [ "PolyPolygonShape3D", "structcom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonShape3D.html", "structcom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonShape3D" ],
    [ "Position3D", "structcom_1_1sun_1_1star_1_1drawing_1_1Position3D.html", "structcom_1_1sun_1_1star_1_1drawing_1_1Position3D" ],
    [ "RectangleShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1RectangleShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1RectangleShape" ],
    [ "RotationDescriptor", "servicecom_1_1sun_1_1star_1_1drawing_1_1RotationDescriptor.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1RotationDescriptor" ],
    [ "ShadowProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1ShadowProperties.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1ShadowProperties" ],
    [ "Shape", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shape" ],
    [ "ShapeCollection", "servicecom_1_1sun_1_1star_1_1drawing_1_1ShapeCollection.html", null ],
    [ "Shapes", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shapes.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1Shapes" ],
    [ "Text", "servicecom_1_1sun_1_1star_1_1drawing_1_1Text.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1Text" ],
    [ "TextProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1TextProperties.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1TextProperties" ],
    [ "TextShape", "servicecom_1_1sun_1_1star_1_1drawing_1_1TextShape.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1TextShape" ],
    [ "TransparencyGradientTable", "servicecom_1_1sun_1_1star_1_1drawing_1_1TransparencyGradientTable.html", "servicecom_1_1sun_1_1star_1_1drawing_1_1TransparencyGradientTable" ],
    [ "XConnectableShape", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XConnectableShape.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XConnectableShape" ],
    [ "XConnectorShape", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XConnectorShape.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XConnectorShape" ],
    [ "XControlShape", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XControlShape.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XControlShape" ],
    [ "XCustomShapeEngine", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XCustomShapeEngine.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XCustomShapeEngine" ],
    [ "XCustomShapeHandle", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XCustomShapeHandle.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XCustomShapeHandle" ],
    [ "XDrawPage", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPage.html", null ],
    [ "XDrawPageDuplicator", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPageDuplicator.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPageDuplicator" ],
    [ "XDrawPageExpander", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPageExpander.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPageExpander" ],
    [ "XDrawPages", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPages.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPages" ],
    [ "XDrawPages2", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPages2.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPages2" ],
    [ "XDrawPagesSupplier", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPagesSupplier.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPagesSupplier" ],
    [ "XDrawPageSummarizer", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPageSummarizer.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPageSummarizer" ],
    [ "XDrawPageSupplier", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPageSupplier.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPageSupplier" ],
    [ "XDrawSubController", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawSubController.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawSubController" ],
    [ "XDrawView", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawView.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawView" ],
    [ "XEnhancedCustomShapeDefaulter", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XEnhancedCustomShapeDefaulter.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XEnhancedCustomShapeDefaulter" ],
    [ "XGluePointsSupplier", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XGluePointsSupplier.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XGluePointsSupplier" ],
    [ "XGraphicExportFilter", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XGraphicExportFilter.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XGraphicExportFilter" ],
    [ "XLayer", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XLayer.html", null ],
    [ "XLayerManager", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XLayerManager.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XLayerManager" ],
    [ "XLayerSupplier", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XLayerSupplier.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XLayerSupplier" ],
    [ "XMasterPagesSupplier", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XMasterPagesSupplier.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XMasterPagesSupplier" ],
    [ "XMasterPageTarget", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XMasterPageTarget.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XMasterPageTarget" ],
    [ "XSelectionFunction", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSelectionFunction.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSelectionFunction" ],
    [ "XShape", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShape.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShape" ],
    [ "XShapeAligner", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeAligner.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeAligner" ],
    [ "XShapeArranger", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeArranger.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeArranger" ],
    [ "XShapeBinder", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeBinder.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeBinder" ],
    [ "XShapeCombiner", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeCombiner.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeCombiner" ],
    [ "XShapeDescriptor", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeDescriptor.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeDescriptor" ],
    [ "XShapeGroup", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeGroup.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeGroup" ],
    [ "XShapeGrouper", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeGrouper.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeGrouper" ],
    [ "XShapeMirror", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeMirror.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeMirror" ],
    [ "XShapes", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes" ],
    [ "XShapes2", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes2.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes2" ],
    [ "XShapes3", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes3.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes3" ],
    [ "XSlidePreviewCacheListener", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCacheListener.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCacheListener" ],
    [ "XSlideSorterSelectionSupplier", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlideSorterSelectionSupplier.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlideSorterSelectionSupplier" ],
    [ "XUniversalShapeDescriptor", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XUniversalShapeDescriptor.html", "interfacecom_1_1sun_1_1star_1_1drawing_1_1XUniversalShapeDescriptor" ],
    [ "CoordinateSequence", "namespacecom_1_1sun_1_1star_1_1drawing.html#a8277e08f09b131243b715893b903e0b9", null ],
    [ "CoordinateSequenceSequence", "namespacecom_1_1sun_1_1star_1_1drawing.html#ad88515aa1b0941ff1dad60f758962772", null ],
    [ "DoubleSequence", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa4364f03dbaab61199ab61bcdde13182", null ],
    [ "DoubleSequenceSequence", "namespacecom_1_1sun_1_1star_1_1drawing.html#a2ccda0208b8cc27a8a70d849c5d4b76e", null ],
    [ "FlagSequence", "namespacecom_1_1sun_1_1star_1_1drawing.html#a5dd92d80424b0a105962411e468bf9ab", null ],
    [ "FlagSequenceSequence", "namespacecom_1_1sun_1_1star_1_1drawing.html#abb1f8aae85aa23771084f01ce9f52f2f", null ],
    [ "PointSequence", "namespacecom_1_1sun_1_1star_1_1drawing.html#a5fba30ad0b948910e5a46d57bb673a3f", null ],
    [ "PointSequenceSequence", "namespacecom_1_1sun_1_1star_1_1drawing.html#a74f8af1a8832994bee18d13ff6855f87", null ],
    [ "Alignment", "namespacecom_1_1sun_1_1star_1_1drawing.html#acdfaca60ec19c0265bac2692d7982726", [
      [ "TOP_LEFT", "namespacecom_1_1sun_1_1star_1_1drawing.html#acdfaca60ec19c0265bac2692d7982726a6b4ed010af97f067c8ba669e400f3f93", null ],
      [ "TOP", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126ab42f8b60865f7ba76c338647dc85870a", null ],
      [ "TOP_RIGHT", "namespacecom_1_1sun_1_1star_1_1drawing.html#acdfaca60ec19c0265bac2692d7982726aab97669fecf009df518a0d2016b86364", null ],
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2349c85ca7362adcde4c67fbd81a4432", null ],
      [ "CENTER", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4c2c10f0a1a5fa20d9f200d0fb5707ada00f6ce13ea7d341a8ed6b99840f4bbd3", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2d192e0d040aa72b0c0e855aaf9462e5", null ],
      [ "BOTTOM_LEFT", "namespacecom_1_1sun_1_1star_1_1drawing.html#acdfaca60ec19c0265bac2692d7982726a6f6b2705d50f7af47405ee7becaabbdb", null ],
      [ "BOTTOM", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126a735adf4f0e2846e5656c8e85c5402273", null ],
      [ "BOTTOM_RIGHT", "namespacecom_1_1sun_1_1star_1_1drawing.html#acdfaca60ec19c0265bac2692d7982726a5bc569072880e473b667c10005c7aefd", null ]
    ] ],
    [ "Arrangement", "namespacecom_1_1sun_1_1star_1_1drawing.html#ac4d32be4f663e5f65aa208c47e1faa81", [
      [ "FRONT", "namespacecom_1_1sun_1_1star_1_1drawing.html#ac4d32be4f663e5f65aa208c47e1faa81a76bd5ec6ea9d8a1b582d8d5e43102a02", null ],
      [ "MORE_FRONT", "namespacecom_1_1sun_1_1star_1_1drawing.html#ac4d32be4f663e5f65aa208c47e1faa81aac9438f6b7f4e3ae860ca4ee186ccd45", null ],
      [ "MORE_BACK", "namespacecom_1_1sun_1_1star_1_1drawing.html#ac4d32be4f663e5f65aa208c47e1faa81a3bb756b0bb55ed79678da31cb815c93c", null ],
      [ "BACK", "namespacecom_1_1sun_1_1star_1_1drawing.html#ac4d32be4f663e5f65aa208c47e1faa81ac921ff2cfc571c1d19b0485d7f6926ee", null ]
    ] ],
    [ "BitmapMode", "namespacecom_1_1sun_1_1star_1_1drawing.html#ad26489b8cfc631a6aa6a1a59fd2e2356", [
      [ "REPEAT", "namespacecom_1_1sun_1_1star_1_1drawing.html#ad26489b8cfc631a6aa6a1a59fd2e2356a972f3df9d279a3d3acc88bcbe4452d51", null ],
      [ "STRETCH", "namespacecom_1_1sun_1_1star_1_1drawing.html#adf031187199b98bb1b6581c7e69d4810a2c9afb70827224be24d66b5e764beb2e", null ],
      [ "NO_REPEAT", "namespacecom_1_1sun_1_1star_1_1drawing.html#ad26489b8cfc631a6aa6a1a59fd2e2356a541c91b041ba0c75df4082618084a207", null ]
    ] ],
    [ "CircleKind", "namespacecom_1_1sun_1_1star_1_1drawing.html#a6a52201f72a50075b45fea2c19340c0e", [
      [ "FULL", "namespacecom_1_1sun_1_1star_1_1drawing.html#a6a52201f72a50075b45fea2c19340c0ead08f8ac0aa8dfb59589824359772459e", null ],
      [ "SECTION", "namespacecom_1_1sun_1_1star_1_1drawing.html#a6a52201f72a50075b45fea2c19340c0eacb7227be6a36b93e485b62e3acddae51", null ],
      [ "CUT", "namespacecom_1_1sun_1_1star_1_1drawing.html#a6a52201f72a50075b45fea2c19340c0ea2ce36c09e2a0142dfc115c74cea4d486", null ],
      [ "ARC", "namespacecom_1_1sun_1_1star_1_1drawing.html#a6a52201f72a50075b45fea2c19340c0ea13b9aed632d3e4c89287d515c88d9e69", null ]
    ] ],
    [ "ColorMode", "namespacecom_1_1sun_1_1star_1_1drawing.html#a0e887cb85702e0dccbf34d7dbe40443f", [
      [ "STANDARD", "namespacecom_1_1sun_1_1star_1_1drawing.html#aba601430b0385cb6c2e7db8f7814cbffa55bfdf3f9bc8b0b7db6c54377404cec3", null ],
      [ "GREYS", "namespacecom_1_1sun_1_1star_1_1drawing.html#a0e887cb85702e0dccbf34d7dbe40443fa47cf1aeca5c66f54227d21721015237c", null ],
      [ "MONO", "namespacecom_1_1sun_1_1star_1_1drawing.html#a0e887cb85702e0dccbf34d7dbe40443fa3828195437a1112429b5c7a3e8780570", null ],
      [ "WATERMARK", "namespacecom_1_1sun_1_1star_1_1drawing.html#a0e887cb85702e0dccbf34d7dbe40443fac142929521131019eb7d538fc52b487a", null ]
    ] ],
    [ "ConnectionType", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa1f0e2efd52935fd01bfece0fbead81f", [
      [ "AUTO", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126a135407ee7af1402d3e49739d9c4ad06b", null ],
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2349c85ca7362adcde4c67fbd81a4432", null ],
      [ "TOP", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126ab42f8b60865f7ba76c338647dc85870a", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2d192e0d040aa72b0c0e855aaf9462e5", null ],
      [ "BOTTOM", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126a735adf4f0e2846e5656c8e85c5402273", null ],
      [ "SPECIAL", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa4142382acc18a0dd48cc4a563e2d168a178b59d22fc550daac4aa4510d459400", null ]
    ] ],
    [ "ConnectorType", "namespacecom_1_1sun_1_1star_1_1drawing.html#a086c6f6507c67c8809b218d90998c5d6", [
      [ "STANDARD", "namespacecom_1_1sun_1_1star_1_1drawing.html#aba601430b0385cb6c2e7db8f7814cbffa55bfdf3f9bc8b0b7db6c54377404cec3", null ],
      [ "CURVE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a086c6f6507c67c8809b218d90998c5d6a2267c8aab80fd31714c264f251e343cf", null ],
      [ "LINE", "namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a6b5b06de3f4a6ecf7e536a72f2b39c4d", null ],
      [ "LINES", "namespacecom_1_1sun_1_1star_1_1drawing.html#a086c6f6507c67c8809b218d90998c5d6a0b25cd15c2c168baf13ac0feb3980f40", null ]
    ] ],
    [ "DashStyle", "namespacecom_1_1sun_1_1star_1_1drawing.html#a89f0dc2e221d6f608088093da27764d1", [
      [ "RECT", "namespacecom_1_1sun_1_1star_1_1drawing.html#a89f0dc2e221d6f608088093da27764d1a8c3b537d3960e767a7d714c89078e508", null ],
      [ "ROUND", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa36e7b530c7d0049f623b0effe54d04fa53c572a1b8255c935b3501df579fc1d9", null ],
      [ "RECTRELATIVE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a89f0dc2e221d6f608088093da27764d1a387b9303f50b275429ad664af91cd581", null ],
      [ "ROUNDRELATIVE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a89f0dc2e221d6f608088093da27764d1ae7577c6205f1147f2273f0363ccba7f0", null ]
    ] ],
    [ "DrawViewMode", "namespacecom_1_1sun_1_1star_1_1drawing.html#a15072729125e991609f3df469a03f611", [
      [ "DRAW", "namespacecom_1_1sun_1_1star_1_1drawing.html#a15072729125e991609f3df469a03f611a61f3c57b6943c85413975507aede78cd", null ],
      [ "NOTES", "namespacecom_1_1sun_1_1star_1_1drawing.html#a15072729125e991609f3df469a03f611a6a1b96949fff07860f4424f8c1ee98a7", null ],
      [ "HANDOUT", "namespacecom_1_1sun_1_1star_1_1drawing.html#a15072729125e991609f3df469a03f611a3e06feb3fd0c434bb5296f915535154a", null ]
    ] ],
    [ "EnhancedCustomShapeTextPathMode", "namespacecom_1_1sun_1_1star_1_1drawing.html#a0babaeb0d04df312f158184b26a302d6", [
      [ "NORMAL", "namespacecom_1_1sun_1_1star_1_1drawing.html#af3965fa427851bc02bfe32c5d95d7406aa0fbc4c1fa19f3ad8f39e5a972ec39d2", null ],
      [ "PATH", "namespacecom_1_1sun_1_1star_1_1drawing.html#a0babaeb0d04df312f158184b26a302d6ad67a493278074cf714b262b33d84739c", null ],
      [ "SHAPE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a0babaeb0d04df312f158184b26a302d6a20f1b6e28cd67b9244936ffc716e5611", null ]
    ] ],
    [ "EscapeDirection", "namespacecom_1_1sun_1_1star_1_1drawing.html#a554864869ec34ebdfb5ecde01c5c5670", [
      [ "SMART", "namespacecom_1_1sun_1_1star_1_1drawing.html#a554864869ec34ebdfb5ecde01c5c5670ad77fe182b2be925d654220a317fa5fbe", null ],
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2349c85ca7362adcde4c67fbd81a4432", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2d192e0d040aa72b0c0e855aaf9462e5", null ],
      [ "UP", "namespacecom_1_1sun_1_1star_1_1drawing.html#a218f9e180f159784cd3e33cef99bfe86ab9396f8576c1edddba6173922f0812ad", null ],
      [ "DOWN", "namespacecom_1_1sun_1_1star_1_1drawing.html#a218f9e180f159784cd3e33cef99bfe86a4ebb08896e48bdf5c496da779cbd955c", null ],
      [ "HORIZONTAL", "namespacecom_1_1sun_1_1star_1_1drawing.html#aac70ce37cdcc7a4bfcf79309db1a438bacf89d3ad9b9e0088c6cfa3a4e0367284", null ],
      [ "VERTICAL", "namespacecom_1_1sun_1_1star_1_1drawing.html#aac70ce37cdcc7a4bfcf79309db1a438ba193b765efb81624e8805076ede96181b", null ]
    ] ],
    [ "FillStyle", "namespacecom_1_1sun_1_1star_1_1drawing.html#a93450c852ea0dc97ffc5168069ed1bc0", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780aa899caa602e4fff675b17cdbab33607ec", null ],
      [ "SOLID", "namespacecom_1_1sun_1_1star_1_1drawing.html#a86e0f5648542856159bb40775c854aa7aa6a25b9de19f145cd62f4b759714908f", null ],
      [ "GRADIENT", "namespacecom_1_1sun_1_1star_1_1drawing.html#a93450c852ea0dc97ffc5168069ed1bc0af12f85c0222e6f70a307308793fe473c", null ],
      [ "HATCH", "namespacecom_1_1sun_1_1star_1_1drawing.html#a93450c852ea0dc97ffc5168069ed1bc0abdd48be6952745331b8e35e12c7ed4ac", null ],
      [ "BITMAP", "namespacecom_1_1sun_1_1star_1_1drawing.html#a93450c852ea0dc97ffc5168069ed1bc0a8c56bb4896292ec6f9ad076faed55450", null ]
    ] ],
    [ "HatchStyle", "namespacecom_1_1sun_1_1star_1_1drawing.html#a021284aa8478781ba1b958b81da7b608", [
      [ "SINGLE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a021284aa8478781ba1b958b81da7b608a3388f7110f6f25a54e215eb75d5d7516", null ],
      [ "DOUBLE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a021284aa8478781ba1b958b81da7b608a33465d1d419b1074fb259ef444609e92", null ],
      [ "TRIPLE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a021284aa8478781ba1b958b81da7b608a844778f8569f0313aad1af8f85429a23", null ]
    ] ],
    [ "HorizontalDimensioning", "namespacecom_1_1sun_1_1star_1_1drawing.html#a6c20b7eb17d1eb1746fddc52487581f9", [
      [ "AUTO", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126a135407ee7af1402d3e49739d9c4ad06b", null ],
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2349c85ca7362adcde4c67fbd81a4432", null ],
      [ "CENTERED", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126adb5c3260b4674bf85aa558c7bff71772", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2d192e0d040aa72b0c0e855aaf9462e5", null ]
    ] ],
    [ "LayerType", "namespacecom_1_1sun_1_1star_1_1drawing.html#a56943a0946e5f15e5e58054b8e7a04a4", [
      [ "LAYOUT", "namespacecom_1_1sun_1_1star_1_1drawing.html#a56943a0946e5f15e5e58054b8e7a04a4af8f713bc0d10a2d2d7b7e61860816992", null ],
      [ "CONTROLSA", "namespacecom_1_1sun_1_1star_1_1drawing.html#a56943a0946e5f15e5e58054b8e7a04a4a150d6dfc23b1824b7c1603cc2a209d61", null ],
      [ "DIMENSIONIANG_LINES", "namespacecom_1_1sun_1_1star_1_1drawing.html#a56943a0946e5f15e5e58054b8e7a04a4acd7a284aab578e3b30cc411abb0eaa97", null ],
      [ "USER_DEFINED", "namespacecom_1_1sun_1_1star_1_1drawing.html#a56943a0946e5f15e5e58054b8e7a04a4aa82bd7068d68be2a0d6f24aa8d6716f2", null ]
    ] ],
    [ "LineCap", "namespacecom_1_1sun_1_1star_1_1drawing.html#a6d67f779dcbc9e19f8bc6cdfbb6c23f8", [
      [ "BUTT", "namespacecom_1_1sun_1_1star_1_1drawing.html#a6d67f779dcbc9e19f8bc6cdfbb6c23f8a02370d8ba13afb6744fab12afd7a859d", null ],
      [ "ROUND", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa36e7b530c7d0049f623b0effe54d04fa53c572a1b8255c935b3501df579fc1d9", null ],
      [ "SQUARE", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa4142382acc18a0dd48cc4a563e2d168aa23fa31f8b7c90db6f39c7b268e98efa", null ]
    ] ],
    [ "LineEndType", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa4142382acc18a0dd48cc4a563e2d168", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780aa899caa602e4fff675b17cdbab33607ec", null ],
      [ "ARROW", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa4142382acc18a0dd48cc4a563e2d168a546eccfedc4dcc8623ed0668f77ef982", null ],
      [ "CIRCLE", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa4142382acc18a0dd48cc4a563e2d168aa79c827759ea48f0735386c4b1188911", null ],
      [ "SQUARE", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa4142382acc18a0dd48cc4a563e2d168aa23fa31f8b7c90db6f39c7b268e98efa", null ],
      [ "SPECIAL", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa4142382acc18a0dd48cc4a563e2d168a178b59d22fc550daac4aa4510d459400", null ]
    ] ],
    [ "LineJoint", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa36e7b530c7d0049f623b0effe54d04f", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780aa899caa602e4fff675b17cdbab33607ec", null ],
      [ "MIDDLE", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa36e7b530c7d0049f623b0effe54d04fa1a2710fb8b50ea593b207d1e79fea574", null ],
      [ "BEVEL", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa36e7b530c7d0049f623b0effe54d04faf87e913355fb50da4e4fe0ae6299ae5a", null ],
      [ "MITER", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa36e7b530c7d0049f623b0effe54d04facc57a1589a12b87457f7a4008027238e", null ],
      [ "ROUND", "namespacecom_1_1sun_1_1star_1_1drawing.html#aa36e7b530c7d0049f623b0effe54d04fa53c572a1b8255c935b3501df579fc1d9", null ]
    ] ],
    [ "LineStyle", "namespacecom_1_1sun_1_1star_1_1drawing.html#a86e0f5648542856159bb40775c854aa7", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780aa899caa602e4fff675b17cdbab33607ec", null ],
      [ "SOLID", "namespacecom_1_1sun_1_1star_1_1drawing.html#a86e0f5648542856159bb40775c854aa7aa6a25b9de19f145cd62f4b759714908f", null ],
      [ "DASH", "namespacecom_1_1sun_1_1star_1_1drawing.html#a86e0f5648542856159bb40775c854aa7a36f7cc172dfe8846b32b3bb288d1221f", null ]
    ] ],
    [ "MeasureKind", "namespacecom_1_1sun_1_1star_1_1drawing.html#aba601430b0385cb6c2e7db8f7814cbff", [
      [ "STANDARD", "namespacecom_1_1sun_1_1star_1_1drawing.html#aba601430b0385cb6c2e7db8f7814cbffa55bfdf3f9bc8b0b7db6c54377404cec3", null ],
      [ "RADIUS", "namespacecom_1_1sun_1_1star_1_1drawing.html#aba601430b0385cb6c2e7db8f7814cbffab599bb1cb8b8b74571549d37220d5e5f", null ]
    ] ],
    [ "MeasureTextHorzPos", "namespacecom_1_1sun_1_1star_1_1drawing.html#a38140d53071a431128aa968be9ce4b7d", [
      [ "AUTO", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126a135407ee7af1402d3e49739d9c4ad06b", null ],
      [ "LEFTOUTSIDE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a38140d53071a431128aa968be9ce4b7da122f6b57646ac923e26dd241ca3af3c6", null ],
      [ "INSIDE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a38140d53071a431128aa968be9ce4b7daaed7c373c0b69cb26c5adb789adb495d", null ],
      [ "RIGHTOUTSIDE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a38140d53071a431128aa968be9ce4b7da7db31733b3be28132220393372922024", null ]
    ] ],
    [ "MeasureTextVertPos", "namespacecom_1_1sun_1_1star_1_1drawing.html#afb97f6590316423181878e8f5f79f087", [
      [ "AUTO", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126a135407ee7af1402d3e49739d9c4ad06b", null ],
      [ "EAST", "namespacecom_1_1sun_1_1star_1_1drawing.html#afb97f6590316423181878e8f5f79f087ab5b3793b961949c817c7c0d99c05dad7", null ],
      [ "BREAKEDLINE", "namespacecom_1_1sun_1_1star_1_1drawing.html#afb97f6590316423181878e8f5f79f087a2912e3a3bd879cb40f38a0b1bcca4a74", null ],
      [ "WEST", "namespacecom_1_1sun_1_1star_1_1drawing.html#afb97f6590316423181878e8f5f79f087ae9449e8683a8199dad36b07a63b2f523", null ],
      [ "CENTERED", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126adb5c3260b4674bf85aa558c7bff71772", null ]
    ] ],
    [ "MirrorAxis", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4a57640f8e0cde4bd2c20b6b00d6affb", [
      [ "VERTICAL", "namespacecom_1_1sun_1_1star_1_1drawing.html#aac70ce37cdcc7a4bfcf79309db1a438ba193b765efb81624e8805076ede96181b", null ],
      [ "HORIZONTAL", "namespacecom_1_1sun_1_1star_1_1drawing.html#aac70ce37cdcc7a4bfcf79309db1a438bacf89d3ad9b9e0088c6cfa3a4e0367284", null ]
    ] ],
    [ "NormalsKind", "namespacecom_1_1sun_1_1star_1_1drawing.html#a2f040e92a1488875fb14c6ecc377630b", [
      [ "SPECIFIC", "namespacecom_1_1sun_1_1star_1_1drawing.html#a2f040e92a1488875fb14c6ecc377630ba5e6bebda0c4b9c9862e0cd0406a5c7ac", null ],
      [ "FLAT", "namespacecom_1_1sun_1_1star_1_1drawing.html#af49ab4b65513d2c0077f76b2227326e9aaf1506082e81f8c89e0cadfe8088bff0", null ],
      [ "SPHERE", "namespacecom_1_1sun_1_1star_1_1drawing.html#ae1e109a5c70543e3b92db3b854fd3acba1748edc4234d3c494e228da3c0156b7a", null ]
    ] ],
    [ "PolygonFlags", "namespacecom_1_1sun_1_1star_1_1drawing.html#af3965fa427851bc02bfe32c5d95d7406", [
      [ "NORMAL", "namespacecom_1_1sun_1_1star_1_1drawing.html#af3965fa427851bc02bfe32c5d95d7406aa0fbc4c1fa19f3ad8f39e5a972ec39d2", null ],
      [ "SMOOTH", "namespacecom_1_1sun_1_1star_1_1drawing.html#af49ab4b65513d2c0077f76b2227326e9aa6484cc80d5b5685032365d926f2089e", null ],
      [ "CONTROL", "namespacecom_1_1sun_1_1star_1_1drawing.html#af3965fa427851bc02bfe32c5d95d7406af722a5faa36087c914da53ebe4711f08", null ],
      [ "SYMMETRIC", "namespacecom_1_1sun_1_1star_1_1drawing.html#af3965fa427851bc02bfe32c5d95d7406a4b2338c5e1fba3b9cfb3a3473dfcc856", null ]
    ] ],
    [ "PolygonKind", "namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6", [
      [ "LINE", "namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a6b5b06de3f4a6ecf7e536a72f2b39c4d", null ],
      [ "POLY", "namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a7d85766d041d397d096dcbc0d7c793fd", null ],
      [ "PLIN", "namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a408176cf894ab276f3d7fc870065e90f", null ],
      [ "PATHLINE", "namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6ab26989303571e39efe894611a7695390", null ],
      [ "PATHFILL", "namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a663213fb9ecc9f835a997e42b9de9b6e", null ],
      [ "FREELINE", "namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a31266386ab2c8bf8f1a1a79a0bd35b32", null ],
      [ "FREEFILL", "namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a689e16f582217550af2b50acd2c0db0c", null ],
      [ "PATHPOLY", "namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a0cd6b63d30c8c017bc6824d11ac6e226", null ],
      [ "PATHPLIN", "namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a3bca1db3f7df1d850b7d3aea61301a69", null ]
    ] ],
    [ "ProjectionMode", "namespacecom_1_1sun_1_1star_1_1drawing.html#a635428fef8d6e4afba288610c9c65bd5", [
      [ "PARALLEL", "namespacecom_1_1sun_1_1star_1_1drawing.html#ae1e109a5c70543e3b92db3b854fd3acba154165f3c0988bf0a9e9defb783b2171", null ],
      [ "PERSPECTIVE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a635428fef8d6e4afba288610c9c65bd5a2c5d7801888c03752f28943ac85d805f", null ]
    ] ],
    [ "RectanglePoint", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827", [
      [ "LEFT_TOP", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a7da02230a1ff90c7f779cbbaf9e91e93", null ],
      [ "MIDDLE_TOP", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a772f9596071bf52805dddd2902ebd35b", null ],
      [ "RIGHT_TOP", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a9b2883e2bfd004a9f220d7a73baeccac", null ],
      [ "LEFT_MIDDLE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a0d98404411ee5451af67ff3fa419bc56", null ],
      [ "MIDDLE_MIDDLE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a3aef99307d6e74d8817bb9dfa20a2a87", null ],
      [ "RIGHT_MIDDLE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a63368eff7313a8e9441fa71d49fa9f71", null ],
      [ "LEFT_BOTTOM", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a8c79964c54afa334cc1053d97ad093d8", null ],
      [ "MIDDLE_BOTTOM", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827ab3816efeb9e5b8ec1d91f83de7c0fc82", null ],
      [ "RIGHT_BOTTOM", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827aee0189be1e9c2df7a06f26b9b145b8df", null ]
    ] ],
    [ "ShadeMode", "namespacecom_1_1sun_1_1star_1_1drawing.html#af49ab4b65513d2c0077f76b2227326e9", [
      [ "FLAT", "namespacecom_1_1sun_1_1star_1_1drawing.html#af49ab4b65513d2c0077f76b2227326e9aaf1506082e81f8c89e0cadfe8088bff0", null ],
      [ "PHONG", "namespacecom_1_1sun_1_1star_1_1drawing.html#af49ab4b65513d2c0077f76b2227326e9ab105fa30ed5e94117ebf6a37008f5e49", null ],
      [ "SMOOTH", "namespacecom_1_1sun_1_1star_1_1drawing.html#af49ab4b65513d2c0077f76b2227326e9aa6484cc80d5b5685032365d926f2089e", null ],
      [ "DRAFT", "namespacecom_1_1sun_1_1star_1_1drawing.html#af49ab4b65513d2c0077f76b2227326e9a0b18dcbaa244a964cf244b6e3e894a28", null ]
    ] ],
    [ "SnapObjectType", "namespacecom_1_1sun_1_1star_1_1drawing.html#aac70ce37cdcc7a4bfcf79309db1a438b", [
      [ "POINT", "namespacecom_1_1sun_1_1star_1_1drawing.html#aac70ce37cdcc7a4bfcf79309db1a438ba15108ccafa3232b9067f889b6156f565", null ],
      [ "VERTICAL", "namespacecom_1_1sun_1_1star_1_1drawing.html#aac70ce37cdcc7a4bfcf79309db1a438ba193b765efb81624e8805076ede96181b", null ],
      [ "HORIZONTAL", "namespacecom_1_1sun_1_1star_1_1drawing.html#aac70ce37cdcc7a4bfcf79309db1a438bacf89d3ad9b9e0088c6cfa3a4e0367284", null ]
    ] ],
    [ "TextAdjust", "namespacecom_1_1sun_1_1star_1_1drawing.html#adf031187199b98bb1b6581c7e69d4810", [
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2349c85ca7362adcde4c67fbd81a4432", null ],
      [ "CENTER", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4c2c10f0a1a5fa20d9f200d0fb5707ada00f6ce13ea7d341a8ed6b99840f4bbd3", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2d192e0d040aa72b0c0e855aaf9462e5", null ],
      [ "BLOCK", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4c2c10f0a1a5fa20d9f200d0fb5707ada3958b6f3119181fbef4c7a72d84918da", null ],
      [ "STRETCH", "namespacecom_1_1sun_1_1star_1_1drawing.html#adf031187199b98bb1b6581c7e69d4810a2c9afb70827224be24d66b5e764beb2e", null ]
    ] ],
    [ "TextAnimationDirection", "namespacecom_1_1sun_1_1star_1_1drawing.html#a218f9e180f159784cd3e33cef99bfe86", [
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2349c85ca7362adcde4c67fbd81a4432", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2d192e0d040aa72b0c0e855aaf9462e5", null ],
      [ "UP", "namespacecom_1_1sun_1_1star_1_1drawing.html#a218f9e180f159784cd3e33cef99bfe86ab9396f8576c1edddba6173922f0812ad", null ],
      [ "DOWN", "namespacecom_1_1sun_1_1star_1_1drawing.html#a218f9e180f159784cd3e33cef99bfe86a4ebb08896e48bdf5c496da779cbd955c", null ]
    ] ],
    [ "TextAnimationKind", "namespacecom_1_1sun_1_1star_1_1drawing.html#a86ab93c592ed65e3f2cd0eebaf5660a2", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780aa899caa602e4fff675b17cdbab33607ec", null ],
      [ "BLINK", "namespacecom_1_1sun_1_1star_1_1drawing.html#a86ab93c592ed65e3f2cd0eebaf5660a2a43e7c26b8df0104b9f389e32ac3f72c7", null ],
      [ "SCROLL", "namespacecom_1_1sun_1_1star_1_1drawing.html#a86ab93c592ed65e3f2cd0eebaf5660a2a0fa7d6bebaf9da084fa40612ca13d2c6", null ],
      [ "ALTERNATE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a86ab93c592ed65e3f2cd0eebaf5660a2a1670a71a1b14f08dbe8a4e18b25f1c6c", null ],
      [ "SLIDE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a86ab93c592ed65e3f2cd0eebaf5660a2ab413da935315f77b927b302b1147552f", null ]
    ] ],
    [ "TextFitToSizeType", "namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780a", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780aa899caa602e4fff675b17cdbab33607ec", null ],
      [ "PROPORTIONAL", "namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780aad35adb33a4bd3162eff7f960ea0ad37a", null ],
      [ "ALLLINES", "namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780aada68f8336a4104e4ef3df568c1a5cbbf", null ],
      [ "AUTOFIT", "namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780aaade56df7229853fa6609540d7e6f3048", null ]
    ] ],
    [ "TextHorizontalAdjust", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386", [
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2349c85ca7362adcde4c67fbd81a4432", null ],
      [ "CENTER", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4c2c10f0a1a5fa20d9f200d0fb5707ada00f6ce13ea7d341a8ed6b99840f4bbd3", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2d192e0d040aa72b0c0e855aaf9462e5", null ],
      [ "BLOCK", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4c2c10f0a1a5fa20d9f200d0fb5707ada3958b6f3119181fbef4c7a72d84918da", null ]
    ] ],
    [ "TextureKind", "namespacecom_1_1sun_1_1star_1_1drawing.html#a36a384629c2a5cfb1a9d019d30923c2b", [
      [ "LUMINANCE", "namespacecom_1_1sun_1_1star_1_1drawing.html#adaf903dffc9b5178ac0a76faef6142f2ae7d1f96466b5f85058f53320c1525724", null ],
      [ "COLOR", "namespacecom_1_1sun_1_1star_1_1drawing.html#adaf903dffc9b5178ac0a76faef6142f2af90824509586333cf45ce757d2711ce3", null ]
    ] ],
    [ "TextureKind2", "namespacecom_1_1sun_1_1star_1_1drawing.html#adaf903dffc9b5178ac0a76faef6142f2", [
      [ "LUMINANCE", "namespacecom_1_1sun_1_1star_1_1drawing.html#adaf903dffc9b5178ac0a76faef6142f2ae7d1f96466b5f85058f53320c1525724", null ],
      [ "INTENSITY", "namespacecom_1_1sun_1_1star_1_1drawing.html#adaf903dffc9b5178ac0a76faef6142f2a2cdcc599a48dff7249efc882c4858e54", null ],
      [ "COLOR", "namespacecom_1_1sun_1_1star_1_1drawing.html#adaf903dffc9b5178ac0a76faef6142f2af90824509586333cf45ce757d2711ce3", null ]
    ] ],
    [ "TextureMode", "namespacecom_1_1sun_1_1star_1_1drawing.html#a54e2c5973b14c9a43a7acf8fc80b3edb", [
      [ "REPLACE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a54e2c5973b14c9a43a7acf8fc80b3edba765ae4f8f09e8a28e363acc11643ed91", null ],
      [ "MODULATE", "namespacecom_1_1sun_1_1star_1_1drawing.html#a54e2c5973b14c9a43a7acf8fc80b3edba17fe14cf4a1d6acfec73bac58c1d9951", null ],
      [ "BLEND", "namespacecom_1_1sun_1_1star_1_1drawing.html#a54e2c5973b14c9a43a7acf8fc80b3edba6ab28e2ebc774a58674a758d3eb36f77", null ]
    ] ],
    [ "TextureProjectionMode", "namespacecom_1_1sun_1_1star_1_1drawing.html#ae1e109a5c70543e3b92db3b854fd3acb", [
      [ "OBJECTSPECIFIC", "namespacecom_1_1sun_1_1star_1_1drawing.html#ae1e109a5c70543e3b92db3b854fd3acba3668dde04e6e254e9823521932670f83", null ],
      [ "PARALLEL", "namespacecom_1_1sun_1_1star_1_1drawing.html#ae1e109a5c70543e3b92db3b854fd3acba154165f3c0988bf0a9e9defb783b2171", null ],
      [ "SPHERE", "namespacecom_1_1sun_1_1star_1_1drawing.html#ae1e109a5c70543e3b92db3b854fd3acba1748edc4234d3c494e228da3c0156b7a", null ]
    ] ],
    [ "TextVerticalAdjust", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4c2c10f0a1a5fa20d9f200d0fb5707ad", [
      [ "TOP", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126ab42f8b60865f7ba76c338647dc85870a", null ],
      [ "CENTER", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4c2c10f0a1a5fa20d9f200d0fb5707ada00f6ce13ea7d341a8ed6b99840f4bbd3", null ],
      [ "BOTTOM", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126a735adf4f0e2846e5656c8e85c5402273", null ],
      [ "BLOCK", "namespacecom_1_1sun_1_1star_1_1drawing.html#a4c2c10f0a1a5fa20d9f200d0fb5707ada3958b6f3119181fbef4c7a72d84918da", null ]
    ] ],
    [ "VerticalDimensioning", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126", [
      [ "AUTO", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126a135407ee7af1402d3e49739d9c4ad06b", null ],
      [ "TOP", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126ab42f8b60865f7ba76c338647dc85870a", null ],
      [ "CENTERED", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126adb5c3260b4674bf85aa558c7bff71772", null ],
      [ "BOTTOM", "namespacecom_1_1sun_1_1star_1_1drawing.html#a3d694e7ac991a1dc3541f7d166f0b126a735adf4f0e2846e5656c8e85c5402273", null ]
    ] ]
];